@@ -32,6 +32,14 @@ class Sprite(Shape):
         self.texture = self.load_texture(value)
         self.loaded = True
 
+    @property
+    def width(self):
+        return self.texture.width
+
+    @property
+    def height(self):
+        return self.texture.height
+
     def __init__(self, image_file, pos=(0, 0), collision_radius=0,
                  rotation_angle=0, scale=1.0, color=WHITE):
         """
@@ -87,5 +95,25 @@ class Sprite(Shape):
     def draw(self):
         if not self.loaded:
             self.load_data()
-        pr.draw_texture_ex(self.texture, self.pos, self.rotation_angle, self.scale, self.color)
+        cx, cy = self.width/2, self.height/2
+        px, py = rotate((cx, cy),(0,0),-self.rotation_angle)
+        print(px, py)
+        x = self.x - px + cx
+        y = self.y - py + cy
+        pr.draw_texture_ex(self.texture, (x, y), self.rotation_angle, self.scale, self.color)
 
+_DEG2RAD=0.01745329251
+
+import math
+
+def rotate(point, origin, degrees):
+    radians = degrees * _DEG2RAD
+    x,y = point
+    offset_x, offset_y = origin
+    adjusted_x = (x - offset_x)
+    adjusted_y = (y - offset_y)
+    cos_rad = math.cos(radians)
+    sin_rad = math.sin(radians)
+    qx = offset_x + cos_rad * adjusted_x + sin_rad * adjusted_y
+    qy = offset_y + -sin_rad * adjusted_x + cos_rad * adjusted_y
+    return qx, qy
\ No newline at end of file
